﻿using System;
using System.Collections.Generic;
using System.Windows;
using Telerik.Windows.Controls;
using Telerik.Windows.Controls.Calendar;

namespace TelerikCalendarTest
{
    public class SpecialDaySelector : DataTemplateSelector
    {
        private List<DateTime> _specialDates;
        private DataTemplate _specialDayTemplate { get; set; }
        private DataTemplate _defaultDayTemplate { get; set; }

        public SpecialDaySelector(List<DateTime> specialDates, DataTemplate specialDayTemplate, DataTemplate defaultTemplate)
        {
            _specialDates = specialDates;
            _specialDayTemplate = specialDayTemplate;
            _defaultDayTemplate = defaultTemplate;
        }

        public override DataTemplate SelectTemplate(object item, DependencyObject container)
        {
            var content = item as CalendarButtonContent;
            if (content != null)
            {
                if (_specialDates.Contains(content.Date))
                {
                    return _specialDayTemplate;
                }
            }

            return _defaultDayTemplate;
        }
    }

    public class RadCalendarBehavior : DependencyObject
    {
        private static void OnSpecialDaysChanged(DependencyObject d, DependencyPropertyChangedEventArgs e)
        {
            var calendar = d as RadCalendar;
            if (e.NewValue != null)
            {
                calendar.DayTemplateSelector = new SpecialDaySelector((List<DateTime>)e.NewValue, GetSpecialDayTemplate(d), GetDefaultTemplate(d));
            }
        }

        public static List<DateTime> GetSpecialDays(DependencyObject obj)
        {
            return (List<DateTime>)obj.GetValue(SpecialDaysProperty);
        }

        public static void SetSpecialDays(DependencyObject obj, List<DateTime> value)
        {
            obj.SetValue(SpecialDaysProperty, value);
        }

        public static readonly DependencyProperty SpecialDaysProperty =
            DependencyProperty.RegisterAttached("SpecialDays", typeof(List<DateTime>), typeof(RadCalendarBehavior), new PropertyMetadata(null, OnSpecialDaysChanged));



        public static DataTemplate GetDefaultTemplate(DependencyObject obj)
        {
            return (DataTemplate)obj.GetValue(DefaultTemplateProperty);
        }

        public static void SetDefaultTemplate(DependencyObject obj, DataTemplate value)
        {
            obj.SetValue(DefaultTemplateProperty, value);
        }

        // Using a DependencyProperty as the backing store for DefaultTemplate.  This enables animation, styling, binding, etc...
        public static readonly DependencyProperty DefaultTemplateProperty =
            DependencyProperty.RegisterAttached("DefaultTemplate", typeof(DataTemplate), typeof(RadCalendarBehavior), new PropertyMetadata(null));


        
        public static DataTemplate GetSpecialDayTemplate(DependencyObject obj)
        {
            return (DataTemplate)obj.GetValue(SpecialDayTemplateProperty);
        }

        public static void SetSpecialDayTemplate(DependencyObject obj, DataTemplate value)
        {
            obj.SetValue(SpecialDayTemplateProperty, value);
        }

        public static readonly DependencyProperty SpecialDayTemplateProperty =
            DependencyProperty.RegisterAttached("SpecialDayTemplate", typeof(DataTemplate), typeof(RadCalendarBehavior), new PropertyMetadata(null));
    }
}
